==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/drawing/Hatch.hpp <==
#ifndef _COM_SUN_STAR_DRAWING_HATCH_HPP_
#define _COM_SUN_STAR_DRAWING_HATCH_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_DRAWING_HATCH_HDL_
#include "com/sun/star/drawing/Hatch.hdl"
#endif

#ifndef _COM_SUN_STAR_DRAWING_HATCHSTYLE_HPP_
#include "com/sun/star/drawing/HatchStyle.hpp"
#endif
#ifndef _COM_SUN_STAR_UTIL_COLOR_HPP_
#include "com/sun/star/util/Color.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace drawing {

inline Hatch::Hatch() SAL_THROW( () )
    : Style(::com::sun::star::drawing::HatchStyle_SINGLE)
    , Color(0)
    , Distance(0)
    , Angle(0)
{
}

inline Hatch::Hatch(const ::com::sun::star::drawing::HatchStyle& Style_, const ::sal_Int32& Color_, const ::sal_Int32& Distance_, const ::sal_Int32& Angle_) SAL_THROW( () )
    : Style(Style_)
    , Color(Color_)
    , Distance(Distance_)
    , Angle(Angle_)
{
}

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::drawing::Hatch const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.drawing.Hatch");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
}

#endif // _COM_SUN_STAR_DRAWING_HATCH_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/drawing/Hatch.hpp <==
#ifndef _COM_SUN_STAR_DRAWING_HATCH_HPP_
#define _COM_SUN_STAR_DRAWING_HATCH_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_DRAWING_HATCH_HDL_
#include "com/sun/star/drawing/Hatch.hdl"
#endif

#ifndef _COM_SUN_STAR_DRAWING_HATCHSTYLE_HPP_
#include "com/sun/star/drawing/HatchStyle.hpp"
#endif
#ifndef _COM_SUN_STAR_UTIL_COLOR_HPP_
#include "com/sun/star/util/Color.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace drawing {

inline Hatch::Hatch() SAL_THROW( () )
    : Style(::com::sun::star::drawing::HatchStyle_SINGLE)
    , Color(0)
    , Distance(0)
    , Angle(0)
{
}

inline Hatch::Hatch(const ::com::sun::star::drawing::HatchStyle& Style_, const ::sal_Int32& Color_, const ::sal_Int32& Distance_, const ::sal_Int32& Angle_) SAL_THROW( () )
    : Style(Style_)
    , Color(Color_)
    , Distance(Distance_)
    , Angle(Angle_)
{
}

} } } }

namespace com { namespace sun { namespace star { namespace drawing {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::drawing::Hatch const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.drawing.Hatch");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
};

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::drawing::Hatch const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::drawing::Hatch >::get();
}

#endif // _COM_SUN_STAR_DRAWING_HATCH_HPP_
